/**
 * @file
 */

(function ($, Drupal, drupalSettings) {
  Drupal.behaviors.help_description = {
    attach: function (context, settings) {
      const parentElements = document.querySelectorAll(".editing-helper-block"); // Select all help sections

      parentElements.forEach((parentElement) => {
        const helpContent = parentElement.querySelector(".help-content"); // Get the specific help content for each section

        if (helpContent) {
          // Check if the event listener is already attached
          if (!parentElement.getAttribute("data-listener-attached")) {
            // Using event delegation on the parent
            parentElement.addEventListener("click", function (event) {
              const clickedElement = event.target;

              // Check if the clicked element is the toggle button
              if (clickedElement.classList.contains("toggle-help")) {
                // Prevent any parent events from being triggered
                event.stopPropagation();

                // Toggle the help content
                if (
                  helpContent.style.visibility === "hidden" ||
                  helpContent.style.visibility === ""
                ) {
                  helpContent.style.visibility = "visible";
                  helpContent.style.maxHeight = helpContent.scrollHeight + "px"; // Expand smoothly
                } else {
                  helpContent.style.maxHeight = 0; // Collapse smoothly
                  setTimeout(function () {
                    helpContent.style.visibility = "hidden";
                  }, 300); // Adjust this timeout to match your transition duration
                }
              }
            });

            // Mark the element as having the event listener attached
            parentElement.setAttribute("data-listener-attached", "true");
          }
        }
      });
    },
  };
})(jQuery, Drupal, drupalSettings);
